@@ -174,7 +174,13 @@ class ParticipantBot(test.Client):
                     bots_module = inspect.getmodule(player_bot)
                     method_calls_fn = getattr(bots_module, 'call_live_method', None)
                     if method_calls_fn:
-                        method = getattr(player_bot.group, live_method_name)
+                        players = {
+                            p.id_in_group: p for p in player_bot.group.get_players()
+                        }
+
+                        def method(id_in_group, data):
+                            return getattr(players[id_in_group], live_method_name)(data)
+
                         method_calls_fn(
                             method=method,
                             case=player_bot.case,
