@@ -28,6 +28,7 @@ from otree.models import Participant, Session
 from otree.session import SESSION_CONFIGS_DICT, SessionConfig
 from otree.views.abstract import AdminSessionPageMixin
 from django.db.models import Case, Value, When
+from otree.timeout import tasks
 
 
 def pretty_name(name):
@@ -295,7 +296,7 @@ class SessionData(AdminSessionPageMixin, vanilla.TemplateView):
         for i, row in enumerate(rows, start=1):
             d_row = OrderedDict()
             # table always starts with participant 1
-            d_row['participant_label'] = 'P{}'.format(i)
+            d_row['numeric_label'] = 'P{}'.format(i)
             for t, v in zip(field_names_json, row):
                 d_row[t] = v
             self.context_json.append(d_row)
@@ -320,7 +321,7 @@ class SessionMonitor(AdminSessionPageMixin, vanilla.TemplateView):
 
         field_names = otree.export.get_field_names_for_live_update(Participant)
         display_names = {
-            '_id_in_session': 'ID in session',
+            '_numeric_label': 'ID in session',
             'code': 'Code',
             'label': 'Label',
             '_current_page': 'Page',
@@ -331,7 +332,7 @@ class SessionMonitor(AdminSessionPageMixin, vanilla.TemplateView):
             '_last_page_timestamp': 'Time on page',
         }
 
-        callable_fields = {'status', '_id_in_session', '_current_page'}
+        callable_fields = {'status', '_numeric_label', '_current_page'}
 
         column_names = [display_names[col] for col in field_names]
 
@@ -518,6 +519,8 @@ class AdvanceSession(vanilla.View):
 
     def post(self, request, session_code):
         session = get_object_or_404(otree.models.Session, code=session_code)
+        if otree.common.USE_REDIS:
+            tasks.set_base_url(request.build_absolute_uri('/'))
         session.advance_last_place_participants()
         return HttpResponse('ok')
 
